@@ -542,15 +542,22 @@ as_gt.gs_design <- function(x,
     x <- x %>%
       gt::tab_footnote(
         footnote = paste0(
-          "Cumulative alpha for final analysis (", x_alpha,
-          ") is less than the full alpha (", full_alpha, ") when
-          the futility bound is non-binding. ",
-          "The smaller value subtracts the probability of
-          crossing a futility bound before ",
-          " crossing an efficacy bound at
-          a later analysis (", full_alpha, " - ",
-          full_alpha - x_alpha, " = ", x_alpha,
-          ") under the null hypothesis."
+          "Cumulative alpha for final analysis ",
+          "(", format(x_alpha, scientific = FALSE), ") ",
+          "is less than the full alpha ",
+          "(", format(full_alpha, scientific = FALSE), ") ",
+          "when the futility bound is non-binding. ",
+          "The smaller value subtracts the probability of ",
+          "crossing a futility bound before ",
+          "crossing an efficacy bound at a later analysis ",
+          "(",
+          format(full_alpha, scientific = FALSE),
+          " - ",
+          format(full_alpha - x_alpha, scientific = FALSE),
+          " = ",
+          format(x_alpha, scientific = FALSE),
+          ") ",
+          "under the null hypothesis."
         ),
         locations = gt::cells_body(
           columns = colname_spannersub[2],
