@@ -29,7 +29,10 @@
 #' @param analysis_time Minimum time of analysis.
 #' @param binding Indicator of whether futility bound is binding;
 #'   default of `FALSE` is recommended.
-#' @param info_scale The information scale for calculation.
+#' @param info_scale Information scale for calculation. Options are:
+#'   - `"h0_h1_info"` (default): variance under both null and alternative hypotheses is used.
+#'   - `"h0_info"`: variance under null hypothesis is used.
+#'   - `"h1_info"`: variance under alternative hypothesis is used.
 #' @param upper Function to compute upper bound.
 #' @param upar Parameters passed to `upper`.
 #' @param lower Function to compute lower bound.
@@ -166,7 +169,7 @@ gs_power_ahr <- function(enroll_rate = tibble(
                          test_upper = TRUE,
                          ratio = 1,
                          binding = FALSE,
-                         info_scale = c(0, 1, 2),
+                         info_scale = c("h0_h1_info", "h0_info", "h1_info"),
                          r = 18,
                          tol = 1e-6,
                          interval = c(.01, 100)) {
@@ -174,15 +177,11 @@ gs_power_ahr <- function(enroll_rate = tibble(
   n_analysis <- max(length(event), length(analysis_time), na.rm = TRUE)
 
   # Get the info_scale
-  info_scale <- if (methods::missingArg(info_scale)) {
-    2
-  } else {
-    match.arg(as.character(info_scale), choices = 0:2)
-  }
+  info_scale <- match.arg(info_scale)
 
   # Check if it is two-sided design or not
   if (identical(lower, gs_b) && (!is.list(lpar))) {
-    if (all(test_lower) == FALSE) {
+    if (all(test_lower == FALSE)) {
       two_sided <- FALSE
       lpar <- rep(-Inf, n_analysis)
     } else {
